package org.af.gMCP.gui.graph.annotations;

public class Ellipse {

	public Ellipse() {
		
	}
}
